# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetDomainsPasswordPolicyResult',
    'AwaitableGetDomainsPasswordPolicyResult',
    'get_domains_password_policy',
    'get_domains_password_policy_output',
]

@pulumi.output_type
class GetDomainsPasswordPolicyResult:
    """
    A collection of values returned by getDomainsPasswordPolicy.
    """
    def __init__(__self__, allowed_chars=None, attribute_sets=None, attributes=None, authorization=None, compartment_ocid=None, configured_password_policy_rules=None, delete_in_progress=None, description=None, dictionary_delimiter=None, dictionary_location=None, dictionary_word_disallowed=None, disallowed_chars=None, disallowed_substrings=None, domain_ocid=None, external_id=None, first_name_disallowed=None, force_password_reset=None, groups=None, id=None, idcs_created_bies=None, idcs_endpoint=None, idcs_last_modified_bies=None, idcs_last_upgraded_in_release=None, idcs_prevented_operations=None, last_name_disallowed=None, lockout_duration=None, max_incorrect_attempts=None, max_length=None, max_repeated_chars=None, max_special_chars=None, metas=None, min_alpha_numerals=None, min_alphas=None, min_length=None, min_lower_case=None, min_numerals=None, min_password_age=None, min_special_chars=None, min_unique_chars=None, min_upper_case=None, name=None, num_passwords_in_history=None, ocid=None, password_expire_warning=None, password_expires_after=None, password_policy_id=None, password_strength=None, priority=None, required_chars=None, resource_type_schema_version=None, schemas=None, starts_with_alphabet=None, tags=None, tenancy_ocid=None, user_name_disallowed=None):
        if allowed_chars and not isinstance(allowed_chars, str):
            raise TypeError("Expected argument 'allowed_chars' to be a str")
        pulumi.set(__self__, "allowed_chars", allowed_chars)
        if attribute_sets and not isinstance(attribute_sets, list):
            raise TypeError("Expected argument 'attribute_sets' to be a list")
        pulumi.set(__self__, "attribute_sets", attribute_sets)
        if attributes and not isinstance(attributes, str):
            raise TypeError("Expected argument 'attributes' to be a str")
        pulumi.set(__self__, "attributes", attributes)
        if authorization and not isinstance(authorization, str):
            raise TypeError("Expected argument 'authorization' to be a str")
        pulumi.set(__self__, "authorization", authorization)
        if compartment_ocid and not isinstance(compartment_ocid, str):
            raise TypeError("Expected argument 'compartment_ocid' to be a str")
        pulumi.set(__self__, "compartment_ocid", compartment_ocid)
        if configured_password_policy_rules and not isinstance(configured_password_policy_rules, list):
            raise TypeError("Expected argument 'configured_password_policy_rules' to be a list")
        pulumi.set(__self__, "configured_password_policy_rules", configured_password_policy_rules)
        if delete_in_progress and not isinstance(delete_in_progress, bool):
            raise TypeError("Expected argument 'delete_in_progress' to be a bool")
        pulumi.set(__self__, "delete_in_progress", delete_in_progress)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if dictionary_delimiter and not isinstance(dictionary_delimiter, str):
            raise TypeError("Expected argument 'dictionary_delimiter' to be a str")
        pulumi.set(__self__, "dictionary_delimiter", dictionary_delimiter)
        if dictionary_location and not isinstance(dictionary_location, str):
            raise TypeError("Expected argument 'dictionary_location' to be a str")
        pulumi.set(__self__, "dictionary_location", dictionary_location)
        if dictionary_word_disallowed and not isinstance(dictionary_word_disallowed, bool):
            raise TypeError("Expected argument 'dictionary_word_disallowed' to be a bool")
        pulumi.set(__self__, "dictionary_word_disallowed", dictionary_word_disallowed)
        if disallowed_chars and not isinstance(disallowed_chars, str):
            raise TypeError("Expected argument 'disallowed_chars' to be a str")
        pulumi.set(__self__, "disallowed_chars", disallowed_chars)
        if disallowed_substrings and not isinstance(disallowed_substrings, list):
            raise TypeError("Expected argument 'disallowed_substrings' to be a list")
        pulumi.set(__self__, "disallowed_substrings", disallowed_substrings)
        if domain_ocid and not isinstance(domain_ocid, str):
            raise TypeError("Expected argument 'domain_ocid' to be a str")
        pulumi.set(__self__, "domain_ocid", domain_ocid)
        if external_id and not isinstance(external_id, str):
            raise TypeError("Expected argument 'external_id' to be a str")
        pulumi.set(__self__, "external_id", external_id)
        if first_name_disallowed and not isinstance(first_name_disallowed, bool):
            raise TypeError("Expected argument 'first_name_disallowed' to be a bool")
        pulumi.set(__self__, "first_name_disallowed", first_name_disallowed)
        if force_password_reset and not isinstance(force_password_reset, bool):
            raise TypeError("Expected argument 'force_password_reset' to be a bool")
        pulumi.set(__self__, "force_password_reset", force_password_reset)
        if groups and not isinstance(groups, list):
            raise TypeError("Expected argument 'groups' to be a list")
        pulumi.set(__self__, "groups", groups)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if idcs_created_bies and not isinstance(idcs_created_bies, list):
            raise TypeError("Expected argument 'idcs_created_bies' to be a list")
        pulumi.set(__self__, "idcs_created_bies", idcs_created_bies)
        if idcs_endpoint and not isinstance(idcs_endpoint, str):
            raise TypeError("Expected argument 'idcs_endpoint' to be a str")
        pulumi.set(__self__, "idcs_endpoint", idcs_endpoint)
        if idcs_last_modified_bies and not isinstance(idcs_last_modified_bies, list):
            raise TypeError("Expected argument 'idcs_last_modified_bies' to be a list")
        pulumi.set(__self__, "idcs_last_modified_bies", idcs_last_modified_bies)
        if idcs_last_upgraded_in_release and not isinstance(idcs_last_upgraded_in_release, str):
            raise TypeError("Expected argument 'idcs_last_upgraded_in_release' to be a str")
        pulumi.set(__self__, "idcs_last_upgraded_in_release", idcs_last_upgraded_in_release)
        if idcs_prevented_operations and not isinstance(idcs_prevented_operations, list):
            raise TypeError("Expected argument 'idcs_prevented_operations' to be a list")
        pulumi.set(__self__, "idcs_prevented_operations", idcs_prevented_operations)
        if last_name_disallowed and not isinstance(last_name_disallowed, bool):
            raise TypeError("Expected argument 'last_name_disallowed' to be a bool")
        pulumi.set(__self__, "last_name_disallowed", last_name_disallowed)
        if lockout_duration and not isinstance(lockout_duration, int):
            raise TypeError("Expected argument 'lockout_duration' to be a int")
        pulumi.set(__self__, "lockout_duration", lockout_duration)
        if max_incorrect_attempts and not isinstance(max_incorrect_attempts, int):
            raise TypeError("Expected argument 'max_incorrect_attempts' to be a int")
        pulumi.set(__self__, "max_incorrect_attempts", max_incorrect_attempts)
        if max_length and not isinstance(max_length, int):
            raise TypeError("Expected argument 'max_length' to be a int")
        pulumi.set(__self__, "max_length", max_length)
        if max_repeated_chars and not isinstance(max_repeated_chars, int):
            raise TypeError("Expected argument 'max_repeated_chars' to be a int")
        pulumi.set(__self__, "max_repeated_chars", max_repeated_chars)
        if max_special_chars and not isinstance(max_special_chars, int):
            raise TypeError("Expected argument 'max_special_chars' to be a int")
        pulumi.set(__self__, "max_special_chars", max_special_chars)
        if metas and not isinstance(metas, list):
            raise TypeError("Expected argument 'metas' to be a list")
        pulumi.set(__self__, "metas", metas)
        if min_alpha_numerals and not isinstance(min_alpha_numerals, int):
            raise TypeError("Expected argument 'min_alpha_numerals' to be a int")
        pulumi.set(__self__, "min_alpha_numerals", min_alpha_numerals)
        if min_alphas and not isinstance(min_alphas, int):
            raise TypeError("Expected argument 'min_alphas' to be a int")
        pulumi.set(__self__, "min_alphas", min_alphas)
        if min_length and not isinstance(min_length, int):
            raise TypeError("Expected argument 'min_length' to be a int")
        pulumi.set(__self__, "min_length", min_length)
        if min_lower_case and not isinstance(min_lower_case, int):
            raise TypeError("Expected argument 'min_lower_case' to be a int")
        pulumi.set(__self__, "min_lower_case", min_lower_case)
        if min_numerals and not isinstance(min_numerals, int):
            raise TypeError("Expected argument 'min_numerals' to be a int")
        pulumi.set(__self__, "min_numerals", min_numerals)
        if min_password_age and not isinstance(min_password_age, int):
            raise TypeError("Expected argument 'min_password_age' to be a int")
        pulumi.set(__self__, "min_password_age", min_password_age)
        if min_special_chars and not isinstance(min_special_chars, int):
            raise TypeError("Expected argument 'min_special_chars' to be a int")
        pulumi.set(__self__, "min_special_chars", min_special_chars)
        if min_unique_chars and not isinstance(min_unique_chars, int):
            raise TypeError("Expected argument 'min_unique_chars' to be a int")
        pulumi.set(__self__, "min_unique_chars", min_unique_chars)
        if min_upper_case and not isinstance(min_upper_case, int):
            raise TypeError("Expected argument 'min_upper_case' to be a int")
        pulumi.set(__self__, "min_upper_case", min_upper_case)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if num_passwords_in_history and not isinstance(num_passwords_in_history, int):
            raise TypeError("Expected argument 'num_passwords_in_history' to be a int")
        pulumi.set(__self__, "num_passwords_in_history", num_passwords_in_history)
        if ocid and not isinstance(ocid, str):
            raise TypeError("Expected argument 'ocid' to be a str")
        pulumi.set(__self__, "ocid", ocid)
        if password_expire_warning and not isinstance(password_expire_warning, int):
            raise TypeError("Expected argument 'password_expire_warning' to be a int")
        pulumi.set(__self__, "password_expire_warning", password_expire_warning)
        if password_expires_after and not isinstance(password_expires_after, int):
            raise TypeError("Expected argument 'password_expires_after' to be a int")
        pulumi.set(__self__, "password_expires_after", password_expires_after)
        if password_policy_id and not isinstance(password_policy_id, str):
            raise TypeError("Expected argument 'password_policy_id' to be a str")
        pulumi.set(__self__, "password_policy_id", password_policy_id)
        if password_strength and not isinstance(password_strength, str):
            raise TypeError("Expected argument 'password_strength' to be a str")
        pulumi.set(__self__, "password_strength", password_strength)
        if priority and not isinstance(priority, int):
            raise TypeError("Expected argument 'priority' to be a int")
        pulumi.set(__self__, "priority", priority)
        if required_chars and not isinstance(required_chars, str):
            raise TypeError("Expected argument 'required_chars' to be a str")
        pulumi.set(__self__, "required_chars", required_chars)
        if resource_type_schema_version and not isinstance(resource_type_schema_version, str):
            raise TypeError("Expected argument 'resource_type_schema_version' to be a str")
        pulumi.set(__self__, "resource_type_schema_version", resource_type_schema_version)
        if schemas and not isinstance(schemas, list):
            raise TypeError("Expected argument 'schemas' to be a list")
        pulumi.set(__self__, "schemas", schemas)
        if starts_with_alphabet and not isinstance(starts_with_alphabet, bool):
            raise TypeError("Expected argument 'starts_with_alphabet' to be a bool")
        pulumi.set(__self__, "starts_with_alphabet", starts_with_alphabet)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if tenancy_ocid and not isinstance(tenancy_ocid, str):
            raise TypeError("Expected argument 'tenancy_ocid' to be a str")
        pulumi.set(__self__, "tenancy_ocid", tenancy_ocid)
        if user_name_disallowed and not isinstance(user_name_disallowed, bool):
            raise TypeError("Expected argument 'user_name_disallowed' to be a bool")
        pulumi.set(__self__, "user_name_disallowed", user_name_disallowed)

    @property
    @pulumi.getter(name="allowedChars")
    def allowed_chars(self) -> str:
        """
        A String value whose contents indicate a set of characters that can appear, in any sequence, in a password value
        """
        return pulumi.get(self, "allowed_chars")

    @property
    @pulumi.getter(name="attributeSets")
    def attribute_sets(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "attribute_sets")

    @property
    @pulumi.getter
    def attributes(self) -> Optional[str]:
        return pulumi.get(self, "attributes")

    @property
    @pulumi.getter
    def authorization(self) -> Optional[str]:
        return pulumi.get(self, "authorization")

    @property
    @pulumi.getter(name="compartmentOcid")
    def compartment_ocid(self) -> str:
        """
        Oracle Cloud Infrastructure Compartment Id (ocid) in which the resource lives.
        """
        return pulumi.get(self, "compartment_ocid")

    @property
    @pulumi.getter(name="configuredPasswordPolicyRules")
    def configured_password_policy_rules(self) -> Sequence['outputs.GetDomainsPasswordPolicyConfiguredPasswordPolicyRuleResult']:
        """
        List of password policy rules that have values set. This map of stringKey:stringValue pairs can be used to aid users while setting/resetting password
        """
        return pulumi.get(self, "configured_password_policy_rules")

    @property
    @pulumi.getter(name="deleteInProgress")
    def delete_in_progress(self) -> bool:
        """
        A boolean flag indicating this resource in the process of being deleted. Usually set to true when synchronous deletion of the resource would take too long.
        """
        return pulumi.get(self, "delete_in_progress")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        A String that describes the password policy
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="dictionaryDelimiter")
    def dictionary_delimiter(self) -> str:
        """
        A delimiter used to separate characters in the dictionary file
        """
        return pulumi.get(self, "dictionary_delimiter")

    @property
    @pulumi.getter(name="dictionaryLocation")
    def dictionary_location(self) -> str:
        """
        A Reference value that contains the URI of a dictionary of words not allowed to appear within a password value
        """
        return pulumi.get(self, "dictionary_location")

    @property
    @pulumi.getter(name="dictionaryWordDisallowed")
    def dictionary_word_disallowed(self) -> bool:
        """
        Indicates whether the password can match a dictionary word
        """
        return pulumi.get(self, "dictionary_word_disallowed")

    @property
    @pulumi.getter(name="disallowedChars")
    def disallowed_chars(self) -> str:
        """
        A String value whose contents indicate a set of characters that cannot appear, in any sequence, in a password value
        """
        return pulumi.get(self, "disallowed_chars")

    @property
    @pulumi.getter(name="disallowedSubstrings")
    def disallowed_substrings(self) -> Sequence[str]:
        """
        A String value whose contents indicate a set of substrings that cannot appear, in any sequence, in a password value
        """
        return pulumi.get(self, "disallowed_substrings")

    @property
    @pulumi.getter(name="domainOcid")
    def domain_ocid(self) -> str:
        """
        Oracle Cloud Infrastructure Domain Id (ocid) in which the resource lives.
        """
        return pulumi.get(self, "domain_ocid")

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> str:
        """
        An identifier for the Resource as defined by the Service Consumer. The externalId may simplify identification of the Resource between Service Consumer and Service Provider by allowing the Consumer to refer to the Resource with its own identifier, obviating the need to store a local mapping between the local identifier of the Resource and the identifier used by the Service Provider. Each Resource MAY include a non-empty externalId value. The value of the externalId attribute is always issued by the Service Consumer and can never be specified by the Service Provider. The Service Provider MUST always interpret the externalId as scoped to the Service Consumer's tenant.
        """
        return pulumi.get(self, "external_id")

    @property
    @pulumi.getter(name="firstNameDisallowed")
    def first_name_disallowed(self) -> bool:
        """
        Indicates a sequence of characters that match the user's first name of given name cannot be the password. Password validation against policy will be ignored if length of first name is less than or equal to 3 characters.
        """
        return pulumi.get(self, "first_name_disallowed")

    @property
    @pulumi.getter(name="forcePasswordReset")
    def force_password_reset(self) -> bool:
        """
        Indicates whether all of the users should be forced to reset their password on the next login (to comply with new password policy changes)
        """
        return pulumi.get(self, "force_password_reset")

    @property
    @pulumi.getter
    def groups(self) -> Sequence['outputs.GetDomainsPasswordPolicyGroupResult']:
        """
        A list of groups that the password policy belongs to.
        """
        return pulumi.get(self, "groups")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        Unique identifier for the SCIM Resource as defined by the Service Provider. Each representation of the Resource MUST include a non-empty id value. This identifier MUST be unique across the Service Provider's entire set of Resources. It MUST be a stable, non-reassignable identifier that does not change when the same Resource is returned in subsequent requests. The value of the id attribute is always issued by the Service Provider and MUST never be specified by the Service Consumer. bulkId: is a reserved keyword and MUST NOT be used in the unique identifier.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="idcsCreatedBies")
    def idcs_created_bies(self) -> Sequence['outputs.GetDomainsPasswordPolicyIdcsCreatedByResult']:
        """
        The User or App who created the Resource
        """
        return pulumi.get(self, "idcs_created_bies")

    @property
    @pulumi.getter(name="idcsEndpoint")
    def idcs_endpoint(self) -> str:
        return pulumi.get(self, "idcs_endpoint")

    @property
    @pulumi.getter(name="idcsLastModifiedBies")
    def idcs_last_modified_bies(self) -> Sequence['outputs.GetDomainsPasswordPolicyIdcsLastModifiedByResult']:
        """
        The User or App who modified the Resource
        """
        return pulumi.get(self, "idcs_last_modified_bies")

    @property
    @pulumi.getter(name="idcsLastUpgradedInRelease")
    def idcs_last_upgraded_in_release(self) -> str:
        """
        The release number when the resource was upgraded.
        """
        return pulumi.get(self, "idcs_last_upgraded_in_release")

    @property
    @pulumi.getter(name="idcsPreventedOperations")
    def idcs_prevented_operations(self) -> Sequence[str]:
        """
        Each value of this attribute specifies an operation that only an internal client may perform on this particular resource.
        """
        return pulumi.get(self, "idcs_prevented_operations")

    @property
    @pulumi.getter(name="lastNameDisallowed")
    def last_name_disallowed(self) -> bool:
        """
        Indicates a sequence of characters that match the user's last name of given name cannot be the password. Password validation against policy will be ignored if length of last name is less than or equal to 3 characters.
        """
        return pulumi.get(self, "last_name_disallowed")

    @property
    @pulumi.getter(name="lockoutDuration")
    def lockout_duration(self) -> int:
        """
        The time period in minutes to lock out a user account when the threshold of invalid login attempts is reached. The available range is from 5 through 1440 minutes (24 hours).
        """
        return pulumi.get(self, "lockout_duration")

    @property
    @pulumi.getter(name="maxIncorrectAttempts")
    def max_incorrect_attempts(self) -> int:
        """
        An integer that represents the maximum number of failed logins before an account is locked
        """
        return pulumi.get(self, "max_incorrect_attempts")

    @property
    @pulumi.getter(name="maxLength")
    def max_length(self) -> int:
        """
        The maximum password length (in characters). A value of 0 or no value indicates no maximum length restriction.
        """
        return pulumi.get(self, "max_length")

    @property
    @pulumi.getter(name="maxRepeatedChars")
    def max_repeated_chars(self) -> int:
        """
        The maximum number of repeated characters allowed in a password.  A value of 0 or no value indicates no such restriction.
        """
        return pulumi.get(self, "max_repeated_chars")

    @property
    @pulumi.getter(name="maxSpecialChars")
    def max_special_chars(self) -> int:
        """
        The maximum number of special characters in a password.  A value of 0 or no value indicates no maximum special characters restriction.
        """
        return pulumi.get(self, "max_special_chars")

    @property
    @pulumi.getter
    def metas(self) -> Sequence['outputs.GetDomainsPasswordPolicyMetaResult']:
        """
        A complex attribute that contains resource metadata. All sub-attributes are OPTIONAL.
        """
        return pulumi.get(self, "metas")

    @property
    @pulumi.getter(name="minAlphaNumerals")
    def min_alpha_numerals(self) -> int:
        """
        The minimum number of a combination of alphabetic and numeric characters in a password.  A value of 0 or no value indicates no minimum alphanumeric character restriction.
        """
        return pulumi.get(self, "min_alpha_numerals")

    @property
    @pulumi.getter(name="minAlphas")
    def min_alphas(self) -> int:
        """
        The minimum number of alphabetic characters in a password.  A value of 0 or no value indicates no minimum alphas restriction.
        """
        return pulumi.get(self, "min_alphas")

    @property
    @pulumi.getter(name="minLength")
    def min_length(self) -> int:
        """
        The minimum password length (in characters). A value of 0 or no value indicates no minimum length restriction.
        """
        return pulumi.get(self, "min_length")

    @property
    @pulumi.getter(name="minLowerCase")
    def min_lower_case(self) -> int:
        """
        The minimum number of lowercase alphabetic characters in a password.  A value of 0 or no value indicates no minimum lowercase restriction.
        """
        return pulumi.get(self, "min_lower_case")

    @property
    @pulumi.getter(name="minNumerals")
    def min_numerals(self) -> int:
        """
        The minimum number of numeric characters in a password.  A value of 0 or no value indicates no minimum numeric character restriction.
        """
        return pulumi.get(self, "min_numerals")

    @property
    @pulumi.getter(name="minPasswordAge")
    def min_password_age(self) -> int:
        """
        Minimum time after which the user can resubmit the reset password request
        """
        return pulumi.get(self, "min_password_age")

    @property
    @pulumi.getter(name="minSpecialChars")
    def min_special_chars(self) -> int:
        """
        The minimum number of special characters in a password. A value of 0 or no value indicates no minimum special characters restriction.
        """
        return pulumi.get(self, "min_special_chars")

    @property
    @pulumi.getter(name="minUniqueChars")
    def min_unique_chars(self) -> int:
        """
        The minimum number of unique characters in a password.  A value of 0 or no value indicates no minimum unique characters restriction.
        """
        return pulumi.get(self, "min_unique_chars")

    @property
    @pulumi.getter(name="minUpperCase")
    def min_upper_case(self) -> int:
        """
        The minimum number of uppercase alphabetic characters in a password. A value of 0 or no value indicates no minimum uppercase restriction.
        """
        return pulumi.get(self, "min_upper_case")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        A String that is the name of the policy to display to the user. This is the only mandatory attribute for a password policy.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="numPasswordsInHistory")
    def num_passwords_in_history(self) -> int:
        """
        The number of passwords that will be kept in history that may not be used as a password
        """
        return pulumi.get(self, "num_passwords_in_history")

    @property
    @pulumi.getter
    def ocid(self) -> str:
        """
        Unique Oracle Cloud Infrastructure identifier for the SCIM Resource.
        """
        return pulumi.get(self, "ocid")

    @property
    @pulumi.getter(name="passwordExpireWarning")
    def password_expire_warning(self) -> int:
        """
        An integer indicating the number of days before which the user should be warned about password expiry.
        """
        return pulumi.get(self, "password_expire_warning")

    @property
    @pulumi.getter(name="passwordExpiresAfter")
    def password_expires_after(self) -> int:
        """
        The number of days after which the password expires automatically
        """
        return pulumi.get(self, "password_expires_after")

    @property
    @pulumi.getter(name="passwordPolicyId")
    def password_policy_id(self) -> str:
        return pulumi.get(self, "password_policy_id")

    @property
    @pulumi.getter(name="passwordStrength")
    def password_strength(self) -> str:
        """
        Indicates whether the password policy is configured as Simple, Standard, or Custom.
        """
        return pulumi.get(self, "password_strength")

    @property
    @pulumi.getter
    def priority(self) -> int:
        """
        Password policy priority
        """
        return pulumi.get(self, "priority")

    @property
    @pulumi.getter(name="requiredChars")
    def required_chars(self) -> str:
        """
        A String value whose contents indicate a set of characters that must appear, in any sequence, in a password value
        """
        return pulumi.get(self, "required_chars")

    @property
    @pulumi.getter(name="resourceTypeSchemaVersion")
    def resource_type_schema_version(self) -> Optional[str]:
        return pulumi.get(self, "resource_type_schema_version")

    @property
    @pulumi.getter
    def schemas(self) -> Sequence[str]:
        """
        REQUIRED. The schemas attribute is an array of Strings which allows introspection of the supported schema version for a SCIM representation as well any schema extensions supported by that representation. Each String value must be a unique URI. This specification defines URIs for User, Group, and a standard \\"enterprise\\" extension. All representations of SCIM schema MUST include a non-zero value array with value(s) of the URIs supported by that representation. Duplicate values MUST NOT be included. Value order is not specified and MUST not impact behavior.
        """
        return pulumi.get(self, "schemas")

    @property
    @pulumi.getter(name="startsWithAlphabet")
    def starts_with_alphabet(self) -> bool:
        """
        Indicates that the password must begin with an alphabetic character
        """
        return pulumi.get(self, "starts_with_alphabet")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetDomainsPasswordPolicyTagResult']:
        """
        A list of tags on this resource.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="tenancyOcid")
    def tenancy_ocid(self) -> str:
        """
        Oracle Cloud Infrastructure Tenant Id (ocid) in which the resource lives.
        """
        return pulumi.get(self, "tenancy_ocid")

    @property
    @pulumi.getter(name="userNameDisallowed")
    def user_name_disallowed(self) -> bool:
        """
        Indicates a sequence of characters that match the username cannot be the password. Password validation against policy will be ignored if length of user name is less than or equal to 3 characters.
        """
        return pulumi.get(self, "user_name_disallowed")


class AwaitableGetDomainsPasswordPolicyResult(GetDomainsPasswordPolicyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDomainsPasswordPolicyResult(
            allowed_chars=self.allowed_chars,
            attribute_sets=self.attribute_sets,
            attributes=self.attributes,
            authorization=self.authorization,
            compartment_ocid=self.compartment_ocid,
            configured_password_policy_rules=self.configured_password_policy_rules,
            delete_in_progress=self.delete_in_progress,
            description=self.description,
            dictionary_delimiter=self.dictionary_delimiter,
            dictionary_location=self.dictionary_location,
            dictionary_word_disallowed=self.dictionary_word_disallowed,
            disallowed_chars=self.disallowed_chars,
            disallowed_substrings=self.disallowed_substrings,
            domain_ocid=self.domain_ocid,
            external_id=self.external_id,
            first_name_disallowed=self.first_name_disallowed,
            force_password_reset=self.force_password_reset,
            groups=self.groups,
            id=self.id,
            idcs_created_bies=self.idcs_created_bies,
            idcs_endpoint=self.idcs_endpoint,
            idcs_last_modified_bies=self.idcs_last_modified_bies,
            idcs_last_upgraded_in_release=self.idcs_last_upgraded_in_release,
            idcs_prevented_operations=self.idcs_prevented_operations,
            last_name_disallowed=self.last_name_disallowed,
            lockout_duration=self.lockout_duration,
            max_incorrect_attempts=self.max_incorrect_attempts,
            max_length=self.max_length,
            max_repeated_chars=self.max_repeated_chars,
            max_special_chars=self.max_special_chars,
            metas=self.metas,
            min_alpha_numerals=self.min_alpha_numerals,
            min_alphas=self.min_alphas,
            min_length=self.min_length,
            min_lower_case=self.min_lower_case,
            min_numerals=self.min_numerals,
            min_password_age=self.min_password_age,
            min_special_chars=self.min_special_chars,
            min_unique_chars=self.min_unique_chars,
            min_upper_case=self.min_upper_case,
            name=self.name,
            num_passwords_in_history=self.num_passwords_in_history,
            ocid=self.ocid,
            password_expire_warning=self.password_expire_warning,
            password_expires_after=self.password_expires_after,
            password_policy_id=self.password_policy_id,
            password_strength=self.password_strength,
            priority=self.priority,
            required_chars=self.required_chars,
            resource_type_schema_version=self.resource_type_schema_version,
            schemas=self.schemas,
            starts_with_alphabet=self.starts_with_alphabet,
            tags=self.tags,
            tenancy_ocid=self.tenancy_ocid,
            user_name_disallowed=self.user_name_disallowed)


def get_domains_password_policy(attribute_sets: Optional[Sequence[str]] = None,
                                attributes: Optional[str] = None,
                                authorization: Optional[str] = None,
                                idcs_endpoint: Optional[str] = None,
                                password_policy_id: Optional[str] = None,
                                resource_type_schema_version: Optional[str] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDomainsPasswordPolicyResult:
    """
    This data source provides details about a specific Password Policy resource in Oracle Cloud Infrastructure Identity Domains service.

    Get a Password Policy

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_password_policy = oci.Identity.get_domains_password_policy(idcs_endpoint=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        password_policy_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        attribute_sets=[],
        attributes="",
        authorization=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        resource_type_schema_version=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param Sequence[str] attribute_sets: A multi-valued list of strings indicating the return type of attribute definition. The specified set of attributes can be fetched by the return type of the attribute. One or more values can be given together to fetch more than one group of attributes. If 'attributes' query parameter is also available, union of the two is fetched. Valid values - all, always, never, request, default. Values are case-insensitive.
    :param str attributes: A comma-delimited string that specifies the names of resource attributes that should be returned in the response. By default, a response that contains resource attributes contains only attributes that are defined in the schema for that resource type as returned=always or returned=default. An attribute that is defined as returned=request is returned in a response only if the request specifies its name in the value of this query parameter. If a request specifies this query parameter, the response contains the attributes that this query parameter specifies, as well as any attribute that is defined as returned=always.
    :param str authorization: The Authorization field value consists of credentials containing the authentication information of the user agent for the realm of the resource being requested.
    :param str idcs_endpoint: The basic endpoint for the identity domain
    :param str password_policy_id: ID of the resource
    :param str resource_type_schema_version: An endpoint-specific schema version number to use in the Request. Allowed version values are Earliest Version or Latest Version as specified in each REST API endpoint description, or any sequential number inbetween. All schema attributes/body parameters are a part of version 1. After version 1, any attributes added or deprecated will be tagged with the version that they were added to or deprecated in. If no version is provided, the latest schema version is returned.
    """
    __args__ = dict()
    __args__['attributeSets'] = attribute_sets
    __args__['attributes'] = attributes
    __args__['authorization'] = authorization
    __args__['idcsEndpoint'] = idcs_endpoint
    __args__['passwordPolicyId'] = password_policy_id
    __args__['resourceTypeSchemaVersion'] = resource_type_schema_version
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Identity/getDomainsPasswordPolicy:getDomainsPasswordPolicy', __args__, opts=opts, typ=GetDomainsPasswordPolicyResult).value

    return AwaitableGetDomainsPasswordPolicyResult(
        allowed_chars=__ret__.allowed_chars,
        attribute_sets=__ret__.attribute_sets,
        attributes=__ret__.attributes,
        authorization=__ret__.authorization,
        compartment_ocid=__ret__.compartment_ocid,
        configured_password_policy_rules=__ret__.configured_password_policy_rules,
        delete_in_progress=__ret__.delete_in_progress,
        description=__ret__.description,
        dictionary_delimiter=__ret__.dictionary_delimiter,
        dictionary_location=__ret__.dictionary_location,
        dictionary_word_disallowed=__ret__.dictionary_word_disallowed,
        disallowed_chars=__ret__.disallowed_chars,
        disallowed_substrings=__ret__.disallowed_substrings,
        domain_ocid=__ret__.domain_ocid,
        external_id=__ret__.external_id,
        first_name_disallowed=__ret__.first_name_disallowed,
        force_password_reset=__ret__.force_password_reset,
        groups=__ret__.groups,
        id=__ret__.id,
        idcs_created_bies=__ret__.idcs_created_bies,
        idcs_endpoint=__ret__.idcs_endpoint,
        idcs_last_modified_bies=__ret__.idcs_last_modified_bies,
        idcs_last_upgraded_in_release=__ret__.idcs_last_upgraded_in_release,
        idcs_prevented_operations=__ret__.idcs_prevented_operations,
        last_name_disallowed=__ret__.last_name_disallowed,
        lockout_duration=__ret__.lockout_duration,
        max_incorrect_attempts=__ret__.max_incorrect_attempts,
        max_length=__ret__.max_length,
        max_repeated_chars=__ret__.max_repeated_chars,
        max_special_chars=__ret__.max_special_chars,
        metas=__ret__.metas,
        min_alpha_numerals=__ret__.min_alpha_numerals,
        min_alphas=__ret__.min_alphas,
        min_length=__ret__.min_length,
        min_lower_case=__ret__.min_lower_case,
        min_numerals=__ret__.min_numerals,
        min_password_age=__ret__.min_password_age,
        min_special_chars=__ret__.min_special_chars,
        min_unique_chars=__ret__.min_unique_chars,
        min_upper_case=__ret__.min_upper_case,
        name=__ret__.name,
        num_passwords_in_history=__ret__.num_passwords_in_history,
        ocid=__ret__.ocid,
        password_expire_warning=__ret__.password_expire_warning,
        password_expires_after=__ret__.password_expires_after,
        password_policy_id=__ret__.password_policy_id,
        password_strength=__ret__.password_strength,
        priority=__ret__.priority,
        required_chars=__ret__.required_chars,
        resource_type_schema_version=__ret__.resource_type_schema_version,
        schemas=__ret__.schemas,
        starts_with_alphabet=__ret__.starts_with_alphabet,
        tags=__ret__.tags,
        tenancy_ocid=__ret__.tenancy_ocid,
        user_name_disallowed=__ret__.user_name_disallowed)


@_utilities.lift_output_func(get_domains_password_policy)
def get_domains_password_policy_output(attribute_sets: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                       attributes: Optional[pulumi.Input[Optional[str]]] = None,
                                       authorization: Optional[pulumi.Input[Optional[str]]] = None,
                                       idcs_endpoint: Optional[pulumi.Input[str]] = None,
                                       password_policy_id: Optional[pulumi.Input[str]] = None,
                                       resource_type_schema_version: Optional[pulumi.Input[Optional[str]]] = None,
                                       opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetDomainsPasswordPolicyResult]:
    """
    This data source provides details about a specific Password Policy resource in Oracle Cloud Infrastructure Identity Domains service.

    Get a Password Policy

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_password_policy = oci.Identity.get_domains_password_policy(idcs_endpoint=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        password_policy_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        attribute_sets=[],
        attributes="",
        authorization=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        resource_type_schema_version=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param Sequence[str] attribute_sets: A multi-valued list of strings indicating the return type of attribute definition. The specified set of attributes can be fetched by the return type of the attribute. One or more values can be given together to fetch more than one group of attributes. If 'attributes' query parameter is also available, union of the two is fetched. Valid values - all, always, never, request, default. Values are case-insensitive.
    :param str attributes: A comma-delimited string that specifies the names of resource attributes that should be returned in the response. By default, a response that contains resource attributes contains only attributes that are defined in the schema for that resource type as returned=always or returned=default. An attribute that is defined as returned=request is returned in a response only if the request specifies its name in the value of this query parameter. If a request specifies this query parameter, the response contains the attributes that this query parameter specifies, as well as any attribute that is defined as returned=always.
    :param str authorization: The Authorization field value consists of credentials containing the authentication information of the user agent for the realm of the resource being requested.
    :param str idcs_endpoint: The basic endpoint for the identity domain
    :param str password_policy_id: ID of the resource
    :param str resource_type_schema_version: An endpoint-specific schema version number to use in the Request. Allowed version values are Earliest Version or Latest Version as specified in each REST API endpoint description, or any sequential number inbetween. All schema attributes/body parameters are a part of version 1. After version 1, any attributes added or deprecated will be tagged with the version that they were added to or deprecated in. If no version is provided, the latest schema version is returned.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'ProtectedDatabaseMetricArgs',
    'ProtectedDatabaseRecoveryServiceSubnetArgs',
    'GetProtectedDatabasesFilterArgs',
    'GetProtectionPoliciesFilterArgs',
    'GetRecoveryServiceSubnetsFilterArgs',
]

@pulumi.input_type
class ProtectedDatabaseMetricArgs:
    def __init__(__self__, *,
                 backup_space_estimate_in_gbs: Optional[pulumi.Input[float]] = None,
                 backup_space_used_in_gbs: Optional[pulumi.Input[float]] = None,
                 current_retention_period_in_seconds: Optional[pulumi.Input[float]] = None,
                 db_size_in_gbs: Optional[pulumi.Input[float]] = None,
                 is_redo_logs_enabled: Optional[pulumi.Input[bool]] = None,
                 retention_period_in_days: Optional[pulumi.Input[float]] = None,
                 unprotected_window_in_seconds: Optional[pulumi.Input[float]] = None):
        """
        :param pulumi.Input[float] backup_space_estimate_in_gbs: The estimated backup storage space, in gigabytes, required to meet the recovery window goal, including foot print and backups for the protected database.
        :param pulumi.Input[float] backup_space_used_in_gbs: Backup storage space, in gigabytes, utilized by the protected database. Oracle charges for the total storage used.
        :param pulumi.Input[float] current_retention_period_in_seconds: Number of seconds backups are currently retained for this database.
        :param pulumi.Input[float] db_size_in_gbs: The estimated space, in gigabytes, consumed by the protected database. The database size is based on the size of the data files in the catalog, and does not include archive logs.
        :param pulumi.Input[bool] is_redo_logs_enabled: The value TRUE indicates that the protected database is configured to use Real-time data protection, and redo-data is sent from the protected database to Recovery Service. Real-time data protection substantially reduces the window of potential data loss that exists between successive archived redo log backups.
        :param pulumi.Input[float] retention_period_in_days: The maximum number of days to retain backups for a protected database.
        :param pulumi.Input[float] unprotected_window_in_seconds: This is the time window when there is data loss exposure. The point after which recovery is impossible unless additional redo is available.  This is the time we received the last backup or last redo-log shipped.
        """
        if backup_space_estimate_in_gbs is not None:
            pulumi.set(__self__, "backup_space_estimate_in_gbs", backup_space_estimate_in_gbs)
        if backup_space_used_in_gbs is not None:
            pulumi.set(__self__, "backup_space_used_in_gbs", backup_space_used_in_gbs)
        if current_retention_period_in_seconds is not None:
            pulumi.set(__self__, "current_retention_period_in_seconds", current_retention_period_in_seconds)
        if db_size_in_gbs is not None:
            pulumi.set(__self__, "db_size_in_gbs", db_size_in_gbs)
        if is_redo_logs_enabled is not None:
            pulumi.set(__self__, "is_redo_logs_enabled", is_redo_logs_enabled)
        if retention_period_in_days is not None:
            pulumi.set(__self__, "retention_period_in_days", retention_period_in_days)
        if unprotected_window_in_seconds is not None:
            pulumi.set(__self__, "unprotected_window_in_seconds", unprotected_window_in_seconds)

    @property
    @pulumi.getter(name="backupSpaceEstimateInGbs")
    def backup_space_estimate_in_gbs(self) -> Optional[pulumi.Input[float]]:
        """
        The estimated backup storage space, in gigabytes, required to meet the recovery window goal, including foot print and backups for the protected database.
        """
        return pulumi.get(self, "backup_space_estimate_in_gbs")

    @backup_space_estimate_in_gbs.setter
    def backup_space_estimate_in_gbs(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "backup_space_estimate_in_gbs", value)

    @property
    @pulumi.getter(name="backupSpaceUsedInGbs")
    def backup_space_used_in_gbs(self) -> Optional[pulumi.Input[float]]:
        """
        Backup storage space, in gigabytes, utilized by the protected database. Oracle charges for the total storage used.
        """
        return pulumi.get(self, "backup_space_used_in_gbs")

    @backup_space_used_in_gbs.setter
    def backup_space_used_in_gbs(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "backup_space_used_in_gbs", value)

    @property
    @pulumi.getter(name="currentRetentionPeriodInSeconds")
    def current_retention_period_in_seconds(self) -> Optional[pulumi.Input[float]]:
        """
        Number of seconds backups are currently retained for this database.
        """
        return pulumi.get(self, "current_retention_period_in_seconds")

    @current_retention_period_in_seconds.setter
    def current_retention_period_in_seconds(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "current_retention_period_in_seconds", value)

    @property
    @pulumi.getter(name="dbSizeInGbs")
    def db_size_in_gbs(self) -> Optional[pulumi.Input[float]]:
        """
        The estimated space, in gigabytes, consumed by the protected database. The database size is based on the size of the data files in the catalog, and does not include archive logs.
        """
        return pulumi.get(self, "db_size_in_gbs")

    @db_size_in_gbs.setter
    def db_size_in_gbs(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "db_size_in_gbs", value)

    @property
    @pulumi.getter(name="isRedoLogsEnabled")
    def is_redo_logs_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        The value TRUE indicates that the protected database is configured to use Real-time data protection, and redo-data is sent from the protected database to Recovery Service. Real-time data protection substantially reduces the window of potential data loss that exists between successive archived redo log backups.
        """
        return pulumi.get(self, "is_redo_logs_enabled")

    @is_redo_logs_enabled.setter
    def is_redo_logs_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_redo_logs_enabled", value)

    @property
    @pulumi.getter(name="retentionPeriodInDays")
    def retention_period_in_days(self) -> Optional[pulumi.Input[float]]:
        """
        The maximum number of days to retain backups for a protected database.
        """
        return pulumi.get(self, "retention_period_in_days")

    @retention_period_in_days.setter
    def retention_period_in_days(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "retention_period_in_days", value)

    @property
    @pulumi.getter(name="unprotectedWindowInSeconds")
    def unprotected_window_in_seconds(self) -> Optional[pulumi.Input[float]]:
        """
        This is the time window when there is data loss exposure. The point after which recovery is impossible unless additional redo is available.  This is the time we received the last backup or last redo-log shipped.
        """
        return pulumi.get(self, "unprotected_window_in_seconds")

    @unprotected_window_in_seconds.setter
    def unprotected_window_in_seconds(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "unprotected_window_in_seconds", value)


@pulumi.input_type
class ProtectedDatabaseRecoveryServiceSubnetArgs:
    def __init__(__self__, *,
                 recovery_service_subnet_id: pulumi.Input[str],
                 state: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] recovery_service_subnet_id: (Updatable) The recovery service subnet OCID.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] state: The current state of the Protected Database.
        """
        pulumi.set(__self__, "recovery_service_subnet_id", recovery_service_subnet_id)
        if state is not None:
            pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter(name="recoveryServiceSubnetId")
    def recovery_service_subnet_id(self) -> pulumi.Input[str]:
        """
        (Updatable) The recovery service subnet OCID.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "recovery_service_subnet_id")

    @recovery_service_subnet_id.setter
    def recovery_service_subnet_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "recovery_service_subnet_id", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        The current state of the Protected Database.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)


@pulumi.input_type
class GetProtectedDatabasesFilterArgs:
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str],
                 regex: Optional[bool] = None):
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)
        if regex is not None:
            pulumi.set(__self__, "regex", regex)

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: str):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")

    @values.setter
    def values(self, value: Sequence[str]):
        pulumi.set(self, "values", value)

    @property
    @pulumi.getter
    def regex(self) -> Optional[bool]:
        return pulumi.get(self, "regex")

    @regex.setter
    def regex(self, value: Optional[bool]):
        pulumi.set(self, "regex", value)


@pulumi.input_type
class GetProtectionPoliciesFilterArgs:
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str],
                 regex: Optional[bool] = None):
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)
        if regex is not None:
            pulumi.set(__self__, "regex", regex)

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: str):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")

    @values.setter
    def values(self, value: Sequence[str]):
        pulumi.set(self, "values", value)

    @property
    @pulumi.getter
    def regex(self) -> Optional[bool]:
        return pulumi.get(self, "regex")

    @regex.setter
    def regex(self, value: Optional[bool]):
        pulumi.set(self, "regex", value)


@pulumi.input_type
class GetRecoveryServiceSubnetsFilterArgs:
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str],
                 regex: Optional[bool] = None):
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)
        if regex is not None:
            pulumi.set(__self__, "regex", regex)

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: str):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")

    @values.setter
    def values(self, value: Sequence[str]):
        pulumi.set(self, "values", value)

    @property
    @pulumi.getter
    def regex(self) -> Optional[bool]:
        return pulumi.get(self, "regex")

    @regex.setter
    def regex(self, value: Optional[bool]):
        pulumi.set(self, "regex", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetImagesResult',
    'AwaitableGetImagesResult',
    'get_images',
    'get_images_output',
]

@pulumi.output_type
class GetImagesResult:
    """
    A collection of values returned by getImages.
    """
    def __init__(__self__, compartment_id=None, display_name=None, filters=None, id=None, images=None, operating_system=None, operating_system_version=None, shape=None, sort_by=None, sort_order=None, state=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if images and not isinstance(images, list):
            raise TypeError("Expected argument 'images' to be a list")
        pulumi.set(__self__, "images", images)
        if operating_system and not isinstance(operating_system, str):
            raise TypeError("Expected argument 'operating_system' to be a str")
        pulumi.set(__self__, "operating_system", operating_system)
        if operating_system_version and not isinstance(operating_system_version, str):
            raise TypeError("Expected argument 'operating_system_version' to be a str")
        pulumi.set(__self__, "operating_system_version", operating_system_version)
        if shape and not isinstance(shape, str):
            raise TypeError("Expected argument 'shape' to be a str")
        pulumi.set(__self__, "shape", shape)
        if sort_by and not isinstance(sort_by, str):
            raise TypeError("Expected argument 'sort_by' to be a str")
        pulumi.set(__self__, "sort_by", sort_by)
        if sort_order and not isinstance(sort_order, str):
            raise TypeError("Expected argument 'sort_order' to be a str")
        pulumi.set(__self__, "sort_order", sort_order)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The OCID of the compartment containing the instance you want to use as the basis for the image.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        """
        A user-friendly name for the image. It does not have to be unique, and it's changeable. Avoid entering confidential information.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetImagesFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def images(self) -> Sequence['outputs.GetImagesImageResult']:
        """
        The list of images.
        """
        return pulumi.get(self, "images")

    @property
    @pulumi.getter(name="operatingSystem")
    def operating_system(self) -> Optional[str]:
        """
        The image's operating system.  Example: `Oracle Linux`
        """
        return pulumi.get(self, "operating_system")

    @property
    @pulumi.getter(name="operatingSystemVersion")
    def operating_system_version(self) -> Optional[str]:
        """
        The image's operating system version.  Example: `7.2`
        """
        return pulumi.get(self, "operating_system_version")

    @property
    @pulumi.getter
    def shape(self) -> Optional[str]:
        return pulumi.get(self, "shape")

    @property
    @pulumi.getter(name="sortBy")
    def sort_by(self) -> Optional[str]:
        return pulumi.get(self, "sort_by")

    @property
    @pulumi.getter(name="sortOrder")
    def sort_order(self) -> Optional[str]:
        return pulumi.get(self, "sort_order")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        The current state of the image.
        """
        return pulumi.get(self, "state")


class AwaitableGetImagesResult(GetImagesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetImagesResult(
            compartment_id=self.compartment_id,
            display_name=self.display_name,
            filters=self.filters,
            id=self.id,
            images=self.images,
            operating_system=self.operating_system,
            operating_system_version=self.operating_system_version,
            shape=self.shape,
            sort_by=self.sort_by,
            sort_order=self.sort_order,
            state=self.state)


def get_images(compartment_id: Optional[str] = None,
               display_name: Optional[str] = None,
               filters: Optional[Sequence[pulumi.InputType['GetImagesFilterArgs']]] = None,
               operating_system: Optional[str] = None,
               operating_system_version: Optional[str] = None,
               shape: Optional[str] = None,
               sort_by: Optional[str] = None,
               sort_order: Optional[str] = None,
               state: Optional[str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetImagesResult:
    """
    This data source provides the list of Images in Oracle Cloud Infrastructure Core service.

    Lists a subset of images available in the specified compartment, including
    [platform images](https://docs.cloud.oracle.com/iaas/Content/Compute/References/images.htm) and
    [custom images](https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/managingcustomimages.htm).
    The list of platform images includes the three most recently published versions
    of each major distribution. The list does not support filtering based on image tags.

    The list of images returned is ordered to first show the recent platform images,
    then all of the custom images.

    **Caution:** Platform images are refreshed regularly. When new images are released, older versions are replaced.
    The image OCIDs remain available, but when the platform image is replaced, the image OCIDs are no longer returned as part of the platform image list.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_images = oci.Core.get_images(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        operating_system=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        operating_system_version=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        shape=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        sort_by=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        sort_order=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
    :param str display_name: A filter to return only resources that match the given display name exactly.
    :param str operating_system: The image's operating system.  Example: `Oracle Linux`
    :param str operating_system_version: The image's operating system version.  Example: `7.2`
    :param str shape: Shape name.
    :param str sort_by: Sort the resources returned, by creation time or display name. Example `TIMECREATED` or `DISPLAYNAME`.
    :param str sort_order: The sort order to use, either ascending (`ASC`) or descending (`DESC`).
    :param str state: A filter to only return resources that match the given lifecycle state.  The state value is case-insensitive.
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['displayName'] = display_name
    __args__['filters'] = filters
    __args__['operatingSystem'] = operating_system
    __args__['operatingSystemVersion'] = operating_system_version
    __args__['shape'] = shape
    __args__['sortBy'] = sort_by
    __args__['sortOrder'] = sort_order
    __args__['state'] = state
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Core/getImages:getImages', __args__, opts=opts, typ=GetImagesResult).value

    return AwaitableGetImagesResult(
        compartment_id=__ret__.compartment_id,
        display_name=__ret__.display_name,
        filters=__ret__.filters,
        id=__ret__.id,
        images=__ret__.images,
        operating_system=__ret__.operating_system,
        operating_system_version=__ret__.operating_system_version,
        shape=__ret__.shape,
        sort_by=__ret__.sort_by,
        sort_order=__ret__.sort_order,
        state=__ret__.state)


@_utilities.lift_output_func(get_images)
def get_images_output(compartment_id: Optional[pulumi.Input[str]] = None,
                      display_name: Optional[pulumi.Input[Optional[str]]] = None,
                      filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetImagesFilterArgs']]]]] = None,
                      operating_system: Optional[pulumi.Input[Optional[str]]] = None,
                      operating_system_version: Optional[pulumi.Input[Optional[str]]] = None,
                      shape: Optional[pulumi.Input[Optional[str]]] = None,
                      sort_by: Optional[pulumi.Input[Optional[str]]] = None,
                      sort_order: Optional[pulumi.Input[Optional[str]]] = None,
                      state: Optional[pulumi.Input[Optional[str]]] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetImagesResult]:
    """
    This data source provides the list of Images in Oracle Cloud Infrastructure Core service.

    Lists a subset of images available in the specified compartment, including
    [platform images](https://docs.cloud.oracle.com/iaas/Content/Compute/References/images.htm) and
    [custom images](https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/managingcustomimages.htm).
    The list of platform images includes the three most recently published versions
    of each major distribution. The list does not support filtering based on image tags.

    The list of images returned is ordered to first show the recent platform images,
    then all of the custom images.

    **Caution:** Platform images are refreshed regularly. When new images are released, older versions are replaced.
    The image OCIDs remain available, but when the platform image is replaced, the image OCIDs are no longer returned as part of the platform image list.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_images = oci.Core.get_images(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        operating_system=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        operating_system_version=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        shape=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        sort_by=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        sort_order=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
    :param str display_name: A filter to return only resources that match the given display name exactly.
    :param str operating_system: The image's operating system.  Example: `Oracle Linux`
    :param str operating_system_version: The image's operating system version.  Example: `7.2`
    :param str shape: Shape name.
    :param str sort_by: Sort the resources returned, by creation time or display name. Example `TIMECREATED` or `DISPLAYNAME`.
    :param str sort_order: The sort order to use, either ascending (`ASC`) or descending (`DESC`).
    :param str state: A filter to only return resources that match the given lifecycle state.  The state value is case-insensitive.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetOdaPrivateEndpointResult',
    'AwaitableGetOdaPrivateEndpointResult',
    'get_oda_private_endpoint',
    'get_oda_private_endpoint_output',
]

@pulumi.output_type
class GetOdaPrivateEndpointResult:
    """
    A collection of values returned by getOdaPrivateEndpoint.
    """
    def __init__(__self__, compartment_id=None, defined_tags=None, description=None, display_name=None, freeform_tags=None, id=None, nsg_ids=None, oda_private_endpoint_id=None, state=None, subnet_id=None, time_created=None, time_updated=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if defined_tags and not isinstance(defined_tags, dict):
            raise TypeError("Expected argument 'defined_tags' to be a dict")
        pulumi.set(__self__, "defined_tags", defined_tags)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if freeform_tags and not isinstance(freeform_tags, dict):
            raise TypeError("Expected argument 'freeform_tags' to be a dict")
        pulumi.set(__self__, "freeform_tags", freeform_tags)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if nsg_ids and not isinstance(nsg_ids, list):
            raise TypeError("Expected argument 'nsg_ids' to be a list")
        pulumi.set(__self__, "nsg_ids", nsg_ids)
        if oda_private_endpoint_id and not isinstance(oda_private_endpoint_id, str):
            raise TypeError("Expected argument 'oda_private_endpoint_id' to be a str")
        pulumi.set(__self__, "oda_private_endpoint_id", oda_private_endpoint_id)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if subnet_id and not isinstance(subnet_id, str):
            raise TypeError("Expected argument 'subnet_id' to be a str")
        pulumi.set(__self__, "subnet_id", subnet_id)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)
        if time_updated and not isinstance(time_updated, str):
            raise TypeError("Expected argument 'time_updated' to be a str")
        pulumi.set(__self__, "time_updated", time_updated)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment that the ODA private endpoint belongs to.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Mapping[str, Any]:
        """
        Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Description of the ODA private endpoint.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        User-defined name for the ODA private endpoint. Avoid entering confidential information. You can change this value.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Mapping[str, Any]:
        """
        Simple key-value pair that is applied without any predefined name, type, or scope. Example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) that was assigned when the ODA private endpoint was created.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="nsgIds")
    def nsg_ids(self) -> Sequence[str]:
        """
        List of [OCIDs](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of [network security groups](https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/networksecuritygroups.htm)
        """
        return pulumi.get(self, "nsg_ids")

    @property
    @pulumi.getter(name="odaPrivateEndpointId")
    def oda_private_endpoint_id(self) -> str:
        return pulumi.get(self, "oda_private_endpoint_id")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The current state of the ODA private endpoint.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the subnet that the private endpoint belongs to.
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        When the resource was created. A date-time string as described in [RFC 3339](https://tools.ietf.org/rfc/rfc3339), section 14.29.
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> str:
        """
        When the resource was last updated. A date-time string as described in [RFC 3339](https://tools.ietf.org/rfc/rfc3339), section 14.29.
        """
        return pulumi.get(self, "time_updated")


class AwaitableGetOdaPrivateEndpointResult(GetOdaPrivateEndpointResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetOdaPrivateEndpointResult(
            compartment_id=self.compartment_id,
            defined_tags=self.defined_tags,
            description=self.description,
            display_name=self.display_name,
            freeform_tags=self.freeform_tags,
            id=self.id,
            nsg_ids=self.nsg_ids,
            oda_private_endpoint_id=self.oda_private_endpoint_id,
            state=self.state,
            subnet_id=self.subnet_id,
            time_created=self.time_created,
            time_updated=self.time_updated)


def get_oda_private_endpoint(oda_private_endpoint_id: Optional[str] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetOdaPrivateEndpointResult:
    """
    This data source provides details about a specific Oda Private Endpoint resource in Oracle Cloud Infrastructure Digital Assistant service.

    Gets the specified ODA Private Endpoint.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_oda_private_endpoint = oci.Oda.get_oda_private_endpoint(oda_private_endpoint_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str oda_private_endpoint_id: Unique ODA Private Endpoint identifier which is the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    """
    __args__ = dict()
    __args__['odaPrivateEndpointId'] = oda_private_endpoint_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Oda/getOdaPrivateEndpoint:getOdaPrivateEndpoint', __args__, opts=opts, typ=GetOdaPrivateEndpointResult).value

    return AwaitableGetOdaPrivateEndpointResult(
        compartment_id=__ret__.compartment_id,
        defined_tags=__ret__.defined_tags,
        description=__ret__.description,
        display_name=__ret__.display_name,
        freeform_tags=__ret__.freeform_tags,
        id=__ret__.id,
        nsg_ids=__ret__.nsg_ids,
        oda_private_endpoint_id=__ret__.oda_private_endpoint_id,
        state=__ret__.state,
        subnet_id=__ret__.subnet_id,
        time_created=__ret__.time_created,
        time_updated=__ret__.time_updated)


@_utilities.lift_output_func(get_oda_private_endpoint)
def get_oda_private_endpoint_output(oda_private_endpoint_id: Optional[pulumi.Input[str]] = None,
                                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetOdaPrivateEndpointResult]:
    """
    This data source provides details about a specific Oda Private Endpoint resource in Oracle Cloud Infrastructure Digital Assistant service.

    Gets the specified ODA Private Endpoint.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_oda_private_endpoint = oci.Oda.get_oda_private_endpoint(oda_private_endpoint_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str oda_private_endpoint_id: Unique ODA Private Endpoint identifier which is the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetDrgRouteRuleResult',
    'AwaitableGetDrgRouteRuleResult',
    'get_drg_route_rule',
    'get_drg_route_rule_output',
]

@pulumi.output_type
class GetDrgRouteRuleResult:
    """
    A collection of values returned by getDrgRouteRule.
    """
    def __init__(__self__, compartment_id=None, defined_tags=None, display_name=None, drg_id=None, drg_route_table_id=None, freeform_tags=None, id=None, import_drg_route_distribution_id=None, is_ecmp_enabled=None, remove_import_trigger=None, state=None, time_created=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if defined_tags and not isinstance(defined_tags, dict):
            raise TypeError("Expected argument 'defined_tags' to be a dict")
        pulumi.set(__self__, "defined_tags", defined_tags)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if drg_id and not isinstance(drg_id, str):
            raise TypeError("Expected argument 'drg_id' to be a str")
        pulumi.set(__self__, "drg_id", drg_id)
        if drg_route_table_id and not isinstance(drg_route_table_id, str):
            raise TypeError("Expected argument 'drg_route_table_id' to be a str")
        pulumi.set(__self__, "drg_route_table_id", drg_route_table_id)
        if freeform_tags and not isinstance(freeform_tags, dict):
            raise TypeError("Expected argument 'freeform_tags' to be a dict")
        pulumi.set(__self__, "freeform_tags", freeform_tags)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if import_drg_route_distribution_id and not isinstance(import_drg_route_distribution_id, str):
            raise TypeError("Expected argument 'import_drg_route_distribution_id' to be a str")
        pulumi.set(__self__, "import_drg_route_distribution_id", import_drg_route_distribution_id)
        if is_ecmp_enabled and not isinstance(is_ecmp_enabled, bool):
            raise TypeError("Expected argument 'is_ecmp_enabled' to be a bool")
        pulumi.set(__self__, "is_ecmp_enabled", is_ecmp_enabled)
        if remove_import_trigger and not isinstance(remove_import_trigger, bool):
            raise TypeError("Expected argument 'remove_import_trigger' to be a bool")
        pulumi.set(__self__, "remove_import_trigger", remove_import_trigger)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment the DRG is in. The DRG route table is always in the same compartment as the DRG.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Mapping[str, Any]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="drgId")
    def drg_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DRG the DRG that contains this route table.
        """
        return pulumi.get(self, "drg_id")

    @property
    @pulumi.getter(name="drgRouteTableId")
    def drg_route_table_id(self) -> str:
        return pulumi.get(self, "drg_route_table_id")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Mapping[str, Any]:
        """
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DRG route table.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="importDrgRouteDistributionId")
    def import_drg_route_distribution_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the import route distribution used to specify how incoming route advertisements from referenced attachments are inserted into the DRG route table.
        """
        return pulumi.get(self, "import_drg_route_distribution_id")

    @property
    @pulumi.getter(name="isEcmpEnabled")
    def is_ecmp_enabled(self) -> bool:
        """
        If you want traffic to be routed using ECMP across your virtual circuits or IPSec tunnels to your on-premises network, enable ECMP on the DRG route table to which these attachments import routes.
        """
        return pulumi.get(self, "is_ecmp_enabled")

    @property
    @pulumi.getter(name="removeImportTrigger")
    def remove_import_trigger(self) -> bool:
        return pulumi.get(self, "remove_import_trigger")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The DRG route table's current state.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The date and time the DRG route table was created, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).  Example: `2016-08-25T21:10:29.600Z`
        """
        return pulumi.get(self, "time_created")


class AwaitableGetDrgRouteRuleResult(GetDrgRouteRuleResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDrgRouteRuleResult(
            compartment_id=self.compartment_id,
            defined_tags=self.defined_tags,
            display_name=self.display_name,
            drg_id=self.drg_id,
            drg_route_table_id=self.drg_route_table_id,
            freeform_tags=self.freeform_tags,
            id=self.id,
            import_drg_route_distribution_id=self.import_drg_route_distribution_id,
            is_ecmp_enabled=self.is_ecmp_enabled,
            remove_import_trigger=self.remove_import_trigger,
            state=self.state,
            time_created=self.time_created)


def get_drg_route_rule(drg_route_table_id: Optional[str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDrgRouteRuleResult:
    """
    This data source provides details about a specific Drg Route Table resource in Oracle Cloud Infrastructure Core service.

    Gets the specified DRG route table's information.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_drg_route_table = oci.Core.get_drg_route_rule(drg_route_table_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str drg_route_table_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DRG route table.
    """
    __args__ = dict()
    __args__['drgRouteTableId'] = drg_route_table_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Core/getDrgRouteRule:getDrgRouteRule', __args__, opts=opts, typ=GetDrgRouteRuleResult).value

    return AwaitableGetDrgRouteRuleResult(
        compartment_id=__ret__.compartment_id,
        defined_tags=__ret__.defined_tags,
        display_name=__ret__.display_name,
        drg_id=__ret__.drg_id,
        drg_route_table_id=__ret__.drg_route_table_id,
        freeform_tags=__ret__.freeform_tags,
        id=__ret__.id,
        import_drg_route_distribution_id=__ret__.import_drg_route_distribution_id,
        is_ecmp_enabled=__ret__.is_ecmp_enabled,
        remove_import_trigger=__ret__.remove_import_trigger,
        state=__ret__.state,
        time_created=__ret__.time_created)


@_utilities.lift_output_func(get_drg_route_rule)
def get_drg_route_rule_output(drg_route_table_id: Optional[pulumi.Input[str]] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetDrgRouteRuleResult]:
    """
    This data source provides details about a specific Drg Route Table resource in Oracle Cloud Infrastructure Core service.

    Gets the specified DRG route table's information.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_drg_route_table = oci.Core.get_drg_route_rule(drg_route_table_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str drg_route_table_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DRG route table.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetFleetBlocklistsResult',
    'AwaitableGetFleetBlocklistsResult',
    'get_fleet_blocklists',
    'get_fleet_blocklists_output',
]

@pulumi.output_type
class GetFleetBlocklistsResult:
    """
    A collection of values returned by getFleetBlocklists.
    """
    def __init__(__self__, filters=None, fleet_id=None, id=None, items=None, managed_instance_id=None, operation=None):
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if fleet_id and not isinstance(fleet_id, str):
            raise TypeError("Expected argument 'fleet_id' to be a str")
        pulumi.set(__self__, "fleet_id", fleet_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if items and not isinstance(items, list):
            raise TypeError("Expected argument 'items' to be a list")
        pulumi.set(__self__, "items", items)
        if managed_instance_id and not isinstance(managed_instance_id, str):
            raise TypeError("Expected argument 'managed_instance_id' to be a str")
        pulumi.set(__self__, "managed_instance_id", managed_instance_id)
        if operation and not isinstance(operation, str):
            raise TypeError("Expected argument 'operation' to be a str")
        pulumi.set(__self__, "operation", operation)

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetFleetBlocklistsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter(name="fleetId")
    def fleet_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the fleet.
        """
        return pulumi.get(self, "fleet_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def items(self) -> Sequence['outputs.GetFleetBlocklistsItemResult']:
        """
        The blocklist
        """
        return pulumi.get(self, "items")

    @property
    @pulumi.getter(name="managedInstanceId")
    def managed_instance_id(self) -> Optional[str]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the related managed instance.
        """
        return pulumi.get(self, "managed_instance_id")

    @property
    @pulumi.getter
    def operation(self) -> Optional[str]:
        """
        The operation type
        """
        return pulumi.get(self, "operation")


class AwaitableGetFleetBlocklistsResult(GetFleetBlocklistsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFleetBlocklistsResult(
            filters=self.filters,
            fleet_id=self.fleet_id,
            id=self.id,
            items=self.items,
            managed_instance_id=self.managed_instance_id,
            operation=self.operation)


def get_fleet_blocklists(filters: Optional[Sequence[pulumi.InputType['GetFleetBlocklistsFilterArgs']]] = None,
                         fleet_id: Optional[str] = None,
                         managed_instance_id: Optional[str] = None,
                         operation: Optional[str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFleetBlocklistsResult:
    """
    This data source provides the list of Fleet Blocklists in Oracle Cloud Infrastructure Jms service.

    Returns a list of blocklist entities contained by a fleet.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_fleet_blocklists = oci.Jms.get_fleet_blocklists(fleet_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        managed_instance_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        operation=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str fleet_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Fleet.
    :param str managed_instance_id: The Fleet-unique identifier of the related managed instance.
    :param str operation: The operation type.
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['fleetId'] = fleet_id
    __args__['managedInstanceId'] = managed_instance_id
    __args__['operation'] = operation
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Jms/getFleetBlocklists:getFleetBlocklists', __args__, opts=opts, typ=GetFleetBlocklistsResult).value

    return AwaitableGetFleetBlocklistsResult(
        filters=__ret__.filters,
        fleet_id=__ret__.fleet_id,
        id=__ret__.id,
        items=__ret__.items,
        managed_instance_id=__ret__.managed_instance_id,
        operation=__ret__.operation)


@_utilities.lift_output_func(get_fleet_blocklists)
def get_fleet_blocklists_output(filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetFleetBlocklistsFilterArgs']]]]] = None,
                                fleet_id: Optional[pulumi.Input[str]] = None,
                                managed_instance_id: Optional[pulumi.Input[Optional[str]]] = None,
                                operation: Optional[pulumi.Input[Optional[str]]] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetFleetBlocklistsResult]:
    """
    This data source provides the list of Fleet Blocklists in Oracle Cloud Infrastructure Jms service.

    Returns a list of blocklist entities contained by a fleet.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_fleet_blocklists = oci.Jms.get_fleet_blocklists(fleet_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        managed_instance_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        operation=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str fleet_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Fleet.
    :param str managed_instance_id: The Fleet-unique identifier of the related managed instance.
    :param str operation: The operation type.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetAuditEventResult',
    'AwaitableGetAuditEventResult',
    'get_audit_event',
    'get_audit_event_output',
]

@pulumi.output_type
class GetAuditEventResult:
    """
    A collection of values returned by getAuditEvent.
    """
    def __init__(__self__, access_level=None, compartment_id=None, compartment_id_in_subtree=None, id=None, items=None, scim_query=None):
        if access_level and not isinstance(access_level, str):
            raise TypeError("Expected argument 'access_level' to be a str")
        pulumi.set(__self__, "access_level", access_level)
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if compartment_id_in_subtree and not isinstance(compartment_id_in_subtree, bool):
            raise TypeError("Expected argument 'compartment_id_in_subtree' to be a bool")
        pulumi.set(__self__, "compartment_id_in_subtree", compartment_id_in_subtree)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if items and not isinstance(items, list):
            raise TypeError("Expected argument 'items' to be a list")
        pulumi.set(__self__, "items", items)
        if scim_query and not isinstance(scim_query, str):
            raise TypeError("Expected argument 'scim_query' to be a str")
        pulumi.set(__self__, "scim_query", scim_query)

    @property
    @pulumi.getter(name="accessLevel")
    def access_level(self) -> Optional[str]:
        return pulumi.get(self, "access_level")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The OCID of the compartment containing the audit event. This is the same audited target database resource comparment.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="compartmentIdInSubtree")
    def compartment_id_in_subtree(self) -> Optional[bool]:
        return pulumi.get(self, "compartment_id_in_subtree")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def items(self) -> Sequence['outputs.GetAuditEventItemResult']:
        """
        Array of audit event summary.
        """
        return pulumi.get(self, "items")

    @property
    @pulumi.getter(name="scimQuery")
    def scim_query(self) -> Optional[str]:
        return pulumi.get(self, "scim_query")


class AwaitableGetAuditEventResult(GetAuditEventResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAuditEventResult(
            access_level=self.access_level,
            compartment_id=self.compartment_id,
            compartment_id_in_subtree=self.compartment_id_in_subtree,
            id=self.id,
            items=self.items,
            scim_query=self.scim_query)


def get_audit_event(access_level: Optional[str] = None,
                    compartment_id: Optional[str] = None,
                    compartment_id_in_subtree: Optional[bool] = None,
                    scim_query: Optional[str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAuditEventResult:
    """
    This data source provides details about a specific Audit Event resource in Oracle Cloud Infrastructure Data Safe service.

    The ListAuditEvents operation returns specified `compartmentId` audit Events only.
    The list does not include any audit Events associated with the `subcompartments` of the specified `compartmentId`.

    The parameter `accessLevel` specifies whether to return only those compartments for which the
    requestor has INSPECT permissions on at least one resource directly
    or indirectly (ACCESSIBLE) (the resource can be in a subcompartment) or to return Not Authorized if
    Principal doesn't have access to even one of the child compartments. This is valid only when
    `compartmentIdInSubtree` is set to `true`.

    The parameter `compartmentIdInSubtree` applies when you perform ListAuditEvents on the
    `compartmentId` passed and when it is set to true, the entire hierarchy of compartments can be returned.
    To get a full list of all compartments and subcompartments in the tenancy (root compartment),
    set the parameter `compartmentIdInSubtree` to true and `accessLevel` to ACCESSIBLE.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_audit_event = oci.DataSafe.get_audit_event(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        access_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        compartment_id_in_subtree=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        scim_query=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str access_level: Valid values are RESTRICTED and ACCESSIBLE. Default is RESTRICTED. Setting this to ACCESSIBLE returns only those compartments for which the user has INSPECT permissions directly or indirectly (permissions can be on a resource in a subcompartment). When set to RESTRICTED permissions are checked and no partial results are displayed.
    :param str compartment_id: A filter to return only resources that match the specified compartment OCID.
    :param bool compartment_id_in_subtree: Default is false. When set to true, the hierarchy of compartments is traversed and all compartments and subcompartments in the tenancy are returned. Depends on the 'accessLevel' setting.
    :param str scim_query: The scimQuery query parameter accepts filter expressions that use the syntax described in Section 3.2.2.2 of the System for Cross-Domain Identity Management (SCIM) specification, which is available at [RFC3339](https://tools.ietf.org/html/draft-ietf-scim-api-12). In SCIM filtering expressions, text, date, and time values must be enclosed in quotation marks, with date and time values using ISO-8601 format. (Numeric and boolean values should not be quoted.)
           
           **Example:** query=(operationTime ge '2021-06-04T01-00-26') and (eventName eq 'LOGON')
    """
    __args__ = dict()
    __args__['accessLevel'] = access_level
    __args__['compartmentId'] = compartment_id
    __args__['compartmentIdInSubtree'] = compartment_id_in_subtree
    __args__['scimQuery'] = scim_query
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:DataSafe/getAuditEvent:getAuditEvent', __args__, opts=opts, typ=GetAuditEventResult).value

    return AwaitableGetAuditEventResult(
        access_level=__ret__.access_level,
        compartment_id=__ret__.compartment_id,
        compartment_id_in_subtree=__ret__.compartment_id_in_subtree,
        id=__ret__.id,
        items=__ret__.items,
        scim_query=__ret__.scim_query)


@_utilities.lift_output_func(get_audit_event)
def get_audit_event_output(access_level: Optional[pulumi.Input[Optional[str]]] = None,
                           compartment_id: Optional[pulumi.Input[str]] = None,
                           compartment_id_in_subtree: Optional[pulumi.Input[Optional[bool]]] = None,
                           scim_query: Optional[pulumi.Input[Optional[str]]] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAuditEventResult]:
    """
    This data source provides details about a specific Audit Event resource in Oracle Cloud Infrastructure Data Safe service.

    The ListAuditEvents operation returns specified `compartmentId` audit Events only.
    The list does not include any audit Events associated with the `subcompartments` of the specified `compartmentId`.

    The parameter `accessLevel` specifies whether to return only those compartments for which the
    requestor has INSPECT permissions on at least one resource directly
    or indirectly (ACCESSIBLE) (the resource can be in a subcompartment) or to return Not Authorized if
    Principal doesn't have access to even one of the child compartments. This is valid only when
    `compartmentIdInSubtree` is set to `true`.

    The parameter `compartmentIdInSubtree` applies when you perform ListAuditEvents on the
    `compartmentId` passed and when it is set to true, the entire hierarchy of compartments can be returned.
    To get a full list of all compartments and subcompartments in the tenancy (root compartment),
    set the parameter `compartmentIdInSubtree` to true and `accessLevel` to ACCESSIBLE.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_audit_event = oci.DataSafe.get_audit_event(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        access_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        compartment_id_in_subtree=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        scim_query=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str access_level: Valid values are RESTRICTED and ACCESSIBLE. Default is RESTRICTED. Setting this to ACCESSIBLE returns only those compartments for which the user has INSPECT permissions directly or indirectly (permissions can be on a resource in a subcompartment). When set to RESTRICTED permissions are checked and no partial results are displayed.
    :param str compartment_id: A filter to return only resources that match the specified compartment OCID.
    :param bool compartment_id_in_subtree: Default is false. When set to true, the hierarchy of compartments is traversed and all compartments and subcompartments in the tenancy are returned. Depends on the 'accessLevel' setting.
    :param str scim_query: The scimQuery query parameter accepts filter expressions that use the syntax described in Section 3.2.2.2 of the System for Cross-Domain Identity Management (SCIM) specification, which is available at [RFC3339](https://tools.ietf.org/html/draft-ietf-scim-api-12). In SCIM filtering expressions, text, date, and time values must be enclosed in quotation marks, with date and time values using ISO-8601 format. (Numeric and boolean values should not be quoted.)
           
           **Example:** query=(operationTime ge '2021-06-04T01-00-26') and (eventName eq 'LOGON')
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetProfileLevelResult',
    'AwaitableGetProfileLevelResult',
    'get_profile_level',
    'get_profile_level_output',
]

@pulumi.output_type
class GetProfileLevelResult:
    """
    A collection of values returned by getProfileLevel.
    """
    def __init__(__self__, compartment_id=None, compartment_id_in_subtree=None, id=None, items=None, name=None, recommendation_name=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if compartment_id_in_subtree and not isinstance(compartment_id_in_subtree, bool):
            raise TypeError("Expected argument 'compartment_id_in_subtree' to be a bool")
        pulumi.set(__self__, "compartment_id_in_subtree", compartment_id_in_subtree)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if items and not isinstance(items, list):
            raise TypeError("Expected argument 'items' to be a list")
        pulumi.set(__self__, "items", items)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if recommendation_name and not isinstance(recommendation_name, str):
            raise TypeError("Expected argument 'recommendation_name' to be a str")
        pulumi.set(__self__, "recommendation_name", recommendation_name)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="compartmentIdInSubtree")
    def compartment_id_in_subtree(self) -> bool:
        return pulumi.get(self, "compartment_id_in_subtree")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def items(self) -> Sequence['outputs.GetProfileLevelItemResult']:
        """
        A collection of profile levels.
        """
        return pulumi.get(self, "items")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        A unique name for the profile level.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="recommendationName")
    def recommendation_name(self) -> Optional[str]:
        """
        The name of the recommendation this profile level applies to.
        """
        return pulumi.get(self, "recommendation_name")


class AwaitableGetProfileLevelResult(GetProfileLevelResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProfileLevelResult(
            compartment_id=self.compartment_id,
            compartment_id_in_subtree=self.compartment_id_in_subtree,
            id=self.id,
            items=self.items,
            name=self.name,
            recommendation_name=self.recommendation_name)


def get_profile_level(compartment_id: Optional[str] = None,
                      compartment_id_in_subtree: Optional[bool] = None,
                      name: Optional[str] = None,
                      recommendation_name: Optional[str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProfileLevelResult:
    """
    This data source provides details about a specific Profile Level resource in Oracle Cloud Infrastructure Optimizer service.

    Lists the existing profile levels.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_profile_level = oci.Optimizer.get_profile_level(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        compartment_id_in_subtree=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        recommendation_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The OCID of the compartment.
    :param bool compartment_id_in_subtree: When set to true, the hierarchy of compartments is traversed and all compartments and subcompartments in the tenancy are returned depending on the the setting of `accessLevel`.
           
           Can only be set to true when performing ListCompartments on the tenancy (root compartment).
    :param str name: Optional. A filter that returns results that match the name specified.
    :param str recommendation_name: Optional. A filter that returns results that match the recommendation name specified.
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['compartmentIdInSubtree'] = compartment_id_in_subtree
    __args__['name'] = name
    __args__['recommendationName'] = recommendation_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Optimizer/getProfileLevel:getProfileLevel', __args__, opts=opts, typ=GetProfileLevelResult).value

    return AwaitableGetProfileLevelResult(
        compartment_id=__ret__.compartment_id,
        compartment_id_in_subtree=__ret__.compartment_id_in_subtree,
        id=__ret__.id,
        items=__ret__.items,
        name=__ret__.name,
        recommendation_name=__ret__.recommendation_name)


@_utilities.lift_output_func(get_profile_level)
def get_profile_level_output(compartment_id: Optional[pulumi.Input[str]] = None,
                             compartment_id_in_subtree: Optional[pulumi.Input[bool]] = None,
                             name: Optional[pulumi.Input[Optional[str]]] = None,
                             recommendation_name: Optional[pulumi.Input[Optional[str]]] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetProfileLevelResult]:
    """
    This data source provides details about a specific Profile Level resource in Oracle Cloud Infrastructure Optimizer service.

    Lists the existing profile levels.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_profile_level = oci.Optimizer.get_profile_level(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        compartment_id_in_subtree=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        recommendation_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The OCID of the compartment.
    :param bool compartment_id_in_subtree: When set to true, the hierarchy of compartments is traversed and all compartments and subcompartments in the tenancy are returned depending on the the setting of `accessLevel`.
           
           Can only be set to true when performing ListCompartments on the tenancy (root compartment).
    :param str name: Optional. A filter that returns results that match the name specified.
    :param str recommendation_name: Optional. A filter that returns results that match the recommendation name specified.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetAwrHubAwrSourcesSummaryResult',
    'AwaitableGetAwrHubAwrSourcesSummaryResult',
    'get_awr_hub_awr_sources_summary',
    'get_awr_hub_awr_sources_summary_output',
]

@pulumi.output_type
class GetAwrHubAwrSourcesSummaryResult:
    """
    A collection of values returned by getAwrHubAwrSourcesSummary.
    """
    def __init__(__self__, awr_hub_id=None, compartment_id=None, id=None, items=None, name=None):
        if awr_hub_id and not isinstance(awr_hub_id, str):
            raise TypeError("Expected argument 'awr_hub_id' to be a str")
        pulumi.set(__self__, "awr_hub_id", awr_hub_id)
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if items and not isinstance(items, list):
            raise TypeError("Expected argument 'items' to be a list")
        pulumi.set(__self__, "items", items)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="awrHubId")
    def awr_hub_id(self) -> str:
        """
        AWR Hub OCID
        """
        return pulumi.get(self, "awr_hub_id")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[str]:
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def items(self) -> Sequence['outputs.GetAwrHubAwrSourcesSummaryItemResult']:
        """
        Array of AwrSource summary objects.
        """
        return pulumi.get(self, "items")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        Database name of the Source database for which AWR Data will be uploaded to AWR Hub.
        """
        return pulumi.get(self, "name")


class AwaitableGetAwrHubAwrSourcesSummaryResult(GetAwrHubAwrSourcesSummaryResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAwrHubAwrSourcesSummaryResult(
            awr_hub_id=self.awr_hub_id,
            compartment_id=self.compartment_id,
            id=self.id,
            items=self.items,
            name=self.name)


def get_awr_hub_awr_sources_summary(awr_hub_id: Optional[str] = None,
                                    compartment_id: Optional[str] = None,
                                    name: Optional[str] = None,
                                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAwrHubAwrSourcesSummaryResult:
    """
    This data source provides details about a specific Awr Hub Awr Sources Summary resource in Oracle Cloud Infrastructure Opsi service.

    Gets a list of summary of AWR Sources.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_awr_hub_awr_sources_summary = oci.Opsi.get_awr_hub_awr_sources_summary(awr_hub_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str awr_hub_id: Unique Awr Hub identifier
    :param str compartment_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
    :param str name: Name for an Awr source database
    """
    __args__ = dict()
    __args__['awrHubId'] = awr_hub_id
    __args__['compartmentId'] = compartment_id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Opsi/getAwrHubAwrSourcesSummary:getAwrHubAwrSourcesSummary', __args__, opts=opts, typ=GetAwrHubAwrSourcesSummaryResult).value

    return AwaitableGetAwrHubAwrSourcesSummaryResult(
        awr_hub_id=__ret__.awr_hub_id,
        compartment_id=__ret__.compartment_id,
        id=__ret__.id,
        items=__ret__.items,
        name=__ret__.name)


@_utilities.lift_output_func(get_awr_hub_awr_sources_summary)
def get_awr_hub_awr_sources_summary_output(awr_hub_id: Optional[pulumi.Input[str]] = None,
                                           compartment_id: Optional[pulumi.Input[Optional[str]]] = None,
                                           name: Optional[pulumi.Input[Optional[str]]] = None,
                                           opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAwrHubAwrSourcesSummaryResult]:
    """
    This data source provides details about a specific Awr Hub Awr Sources Summary resource in Oracle Cloud Infrastructure Opsi service.

    Gets a list of summary of AWR Sources.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_awr_hub_awr_sources_summary = oci.Opsi.get_awr_hub_awr_sources_summary(awr_hub_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str awr_hub_id: Unique Awr Hub identifier
    :param str compartment_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
    :param str name: Name for an Awr source database
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetMessagesResult',
    'AwaitableGetMessagesResult',
    'get_messages',
    'get_messages_output',
]

@pulumi.output_type
class GetMessagesResult:
    """
    A collection of values returned by getMessages.
    """
    def __init__(__self__, deployment_id=None, deployment_messages_collections=None, filters=None, id=None):
        if deployment_id and not isinstance(deployment_id, str):
            raise TypeError("Expected argument 'deployment_id' to be a str")
        pulumi.set(__self__, "deployment_id", deployment_id)
        if deployment_messages_collections and not isinstance(deployment_messages_collections, list):
            raise TypeError("Expected argument 'deployment_messages_collections' to be a list")
        pulumi.set(__self__, "deployment_messages_collections", deployment_messages_collections)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="deploymentId")
    def deployment_id(self) -> str:
        return pulumi.get(self, "deployment_id")

    @property
    @pulumi.getter(name="deploymentMessagesCollections")
    def deployment_messages_collections(self) -> Sequence['outputs.GetMessagesDeploymentMessagesCollectionResult']:
        """
        The list of deployment_messages_collection.
        """
        return pulumi.get(self, "deployment_messages_collections")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetMessagesFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetMessagesResult(GetMessagesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMessagesResult(
            deployment_id=self.deployment_id,
            deployment_messages_collections=self.deployment_messages_collections,
            filters=self.filters,
            id=self.id)


def get_messages(deployment_id: Optional[str] = None,
                 filters: Optional[Sequence[pulumi.InputType['GetMessagesFilterArgs']]] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetMessagesResult:
    """
    This data source provides the list of Messages in Oracle Cloud Infrastructure Golden Gate service.

    Lists the DeploymentMessages for a deployment. The sorting order is not important. By default first will be Upgrade message, next Exception message and then Storage Utilization message.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_messages = oci.GoldenGate.get_messages(deployment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str deployment_id: A unique Deployment identifier.
    """
    __args__ = dict()
    __args__['deploymentId'] = deployment_id
    __args__['filters'] = filters
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:GoldenGate/getMessages:getMessages', __args__, opts=opts, typ=GetMessagesResult).value

    return AwaitableGetMessagesResult(
        deployment_id=__ret__.deployment_id,
        deployment_messages_collections=__ret__.deployment_messages_collections,
        filters=__ret__.filters,
        id=__ret__.id)


@_utilities.lift_output_func(get_messages)
def get_messages_output(deployment_id: Optional[pulumi.Input[str]] = None,
                        filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetMessagesFilterArgs']]]]] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetMessagesResult]:
    """
    This data source provides the list of Messages in Oracle Cloud Infrastructure Golden Gate service.

    Lists the DeploymentMessages for a deployment. The sorting order is not important. By default first will be Upgrade message, next Exception message and then Storage Utilization message.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_messages = oci.GoldenGate.get_messages(deployment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str deployment_id: A unique Deployment identifier.
    """
    ...
